@@ -30,6 +30,10 @@ class FilesystemSerializer(serializers.ModelSerializer):
 class DriveSerializer(NetBoxModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
     url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:drive-detail")
+    content_type = ContentTypeField(
+        queryset=ContentType.objects.all()
+    )
+    object = serializers.SerializerMethodField(read_only=True)
 
     class Meta:
         model = Drive
@@ -40,6 +44,9 @@ class DriveSerializer(NetBoxModelSerializer):
             "size",
             "cluster",
             "identifier",
+            'content_type',
+            'object_id',
+            'object',
             "description",
             "created",
             "last_updated",
