@@ -9,7 +9,8 @@ from netbox_storage.api.views import (
     LinuxDeviceViewSet,
     LogicalVolumeViewSet,
     PhysicalVolumeViewSet,
-    VolumeGroupViewSet
+    VolumeGroupViewSet,
+    TemplateConfigurationDriveViewSet
 )
 
 router = NetBoxRouter()
@@ -23,5 +24,6 @@ router.register("linuxdevice", LinuxDeviceViewSet)
 router.register("logicalvolume", LogicalVolumeViewSet)
 router.register("physicalvolume", PhysicalVolumeViewSet)
 router.register("volumegroup", VolumeGroupViewSet)
+router.register("templateconfigurationdrive", TemplateConfigurationDriveViewSet)
 
 urlpatterns = router.urls
