@@ -6,13 +6,13 @@ from netbox.api.viewsets import NetBoxModelViewSet
 from netbox_storage.api.serializers import (
     DriveSerializer,
     FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer, LinuxDeviceSerializer, LogicalVolumeSerializer,
-    PhysicalVolumeSerializer, VolumeGroupSerializer
+    PhysicalVolumeSerializer, VolumeGroupSerializer, TemplateConfigurationDriveSerializer
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
     PartitionFilter, MountedVolumeFilter, LinuxDeviceFilter, PhysicalVolumeFilter, VolumeGroupFilter, \
-    LogicalVolumeFilter
+    LogicalVolumeFilter, TemplateConfigurationDriveFilter
 from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice, LogicalVolume, \
-    PhysicalVolume, VolumeGroup
+    PhysicalVolume, VolumeGroup, TemplateConfigurationDrive
 
 
 class NetboxStorageRootView(APIRootView):
@@ -118,3 +118,15 @@ class VolumeGroupViewSet(NetBoxModelViewSet):
         volumegroup = VolumeGroup.objects.filter(volumegroup__id=pk)
         serializer = VolumeGroupSerializer(volumegroup, many=True, context={"request": request})
         return Response(serializer.data)
+
+
+class TemplateConfigurationDriveViewSet(NetBoxModelViewSet):
+    queryset = TemplateConfigurationDrive.objects.all()
+    serializer_class = TemplateConfigurationDriveSerializer
+    filterset_class = TemplateConfigurationDriveFilter
+
+    @action(detail=True, methods=["get"])
+    def templateconfigurationdrive(self, request, pk=None):
+        templateconfigurationdrive = TemplateConfigurationDrive.objects.filter(volumegroup__id=pk)
+        serializer = TemplateConfigurationDriveSerializer(templateconfigurationdrive, many=True, context={"request": request})
+        return Response(serializer.data)
