@@ -3,6 +3,7 @@ from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
     FloatField,
+    HiddenInput
 )
 
 from dcim.models import Platform
@@ -98,26 +99,33 @@ class DriveCreateForm(NetBoxModelForm):
             "size",
             "cluster",
             "description",
+            'content_type',
+            'object_id',
         )
+        widgets = {
+            'content_type': HiddenInput(),
+            'object_id': HiddenInput(),
+        }
 
     def save(self, *args, **kwargs):
         if self.cleaned_data['virtual_machine']:
-            number_of_hard_drives = StorageConfigurationDrive.objects.filter(virtual_machine=self.cleaned_data['virtual_machine']).count() or 0
-            self.instance.identifier = f'Hard Drive {number_of_hard_drives + 1}'
-            drive = super().save(*args, **kwargs)
-            StorageConfigurationDrive.objects.create(virtual_machine=self.cleaned_data['virtual_machine'], drive=drive)
+            parent_object_type = ContentType.objects.get(app_label='virtualization', model='virtualmachine').pk
+            parent_object_pk = self.cleaned_data['virtual_machine'].pk
         else:
-            number_of_hard_drives = TemplateConfigurationDrive.objects.filter(platform=self.cleaned_data['platform']).count() or 0
-            self.instance.identifier = f'Hard Drive {number_of_hard_drives + 1}'
-            drive = super().save(*args, **kwargs)
-            if 'windows' not in str(self.cleaned_data['platform']).lower():
-                drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-                LinuxDevice.objects.create(device=drive.device_name(),
-                                           type='Disk',
-                                           size=self.cleaned_data['size'],
-                                           object_id=drive.pk,
-                                           content_type_id=drive_type_pk)
-            TemplateConfigurationDrive.objects.create(platform=self.cleaned_data['platform'], drive=drive)
+            parent_object_type = ContentType.objects.get(app_label='dcim', model='platform').pk
+            parent_object_pk = self.cleaned_data['platform'].pk
+
+        number_of_drives = Drive.objects.filter(object_id=parent_object_pk, content_type_id=parent_object_type).count() or 0
+        self.instance.identifier = f'Hard Drive {number_of_drives + 1}'
+        drive = super().save(*args, **kwargs)
+
+        if self.cleaned_data['platform'] and 'windows' not in str(self.cleaned_data['platform']).lower():
+            drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+            LinuxDevice.objects.create(device=drive.device_name(),
+                                       type='Disk',
+                                       size=self.cleaned_data['size'],
+                                       object_id=drive.pk,
+                                       content_type_id=drive_type_pk)
         return drive
 
 
@@ -169,7 +177,7 @@ class DriveEditForm(NetBoxModelForm):
     def save(self, *args, **kwargs):
         drive = super().save(*args, **kwargs)
         drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-        linux_device_drive = LinuxDevice.objects.get(object_id=drive.pk,content_type_id=drive_type_pk)
+        linux_device_drive = LinuxDevice.objects.get(object_id=drive.pk, content_type_id=drive_type_pk)
         linux_device_drive.size = self.cleaned_data['size']
         linux_device_drive.save()
         return drive
