@@ -1,3 +1,4 @@
+import django_filters
 from django.forms import (
     CharField, FloatField, HiddenInput
 )
@@ -8,8 +9,10 @@ from netbox.forms import (
     NetBoxModelImportForm,
     NetBoxModelForm,
 )
+from netbox_storage.choices import DeviceTypeChoices
 
 from netbox_storage.models import LinuxDevice
+from utilities.forms import DynamicModelChoiceField, ChoiceField, add_blank_choice, StaticSelect
 
 
 class LinuxDeviceForm(NetBoxModelForm):
@@ -17,10 +20,12 @@ class LinuxDeviceForm(NetBoxModelForm):
         label="Device Name",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
-    type = CharField(
+    type = ChoiceField(
+        choices=add_blank_choice(DeviceTypeChoices),
         label="Device Type",
         help_text="The type of the device e.g. Disk, Partition, LVM",
-        max_length=255,
+        initial='',
+        widget=StaticSelect()
     )
     size = FloatField(
         label="Size",
