@@ -74,19 +74,28 @@ class Drive(NetBoxModel):
     identifier = models.CharField(
         max_length=255,
     )
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
+    )
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
+    )
     description = models.CharField(
         max_length=255,
         blank=True,
     )
 
-    clone_fields = ['cluster', 'size', 'identifier', 'description']
+    clone_fields = ['cluster', 'size', 'identifier', 'content_type', 'object_id', 'description']
 
     prerequisite_models = (
         'virtualization.Cluster',
     )
 
     class Meta:
-        ordering = ['size']
+        ordering = ['content_type', 'object_id', 'identifier', 'cluster', 'size']
 
     def __str__(self):
         return f'{self.identifier} ({self.size} GB {self.cluster})'
@@ -382,7 +391,7 @@ class TemplateConfigurationDrive(NetBoxModel):
     #     return reverse('plugins:netbox_storage:storageconfiguration', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f'Template Configuration of the Platform {self.platform}'
+        return f'Template Configuration of the Platform {self.platform} {self.drive}'
 
 
 class MountedVolume(NetBoxModel):
