@@ -46,11 +46,12 @@ class PlatformTemplateContent(PluginTemplateExtension):
 
     def right_page(self):
         obj = self.context.get("object")
+        parent_object_type = ContentType.objects.get(app_label='dcim', model='platform').pk
+
         if obj.name.lower().__contains__('windows'):
-            drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
+            drives = Drive.objects.filter(content_type=parent_object_type, object_id=obj.pk)
             partition_dict = {}
-            for drive_id in drives_id:
-                drive = Drive.objects.get(pk=drive_id['drive'])
+            for drive in drives:
                 if Partition.objects.filter(drive=drive).count() == 0:
                     partition_dict[drive] = None
                 else:
@@ -62,17 +63,14 @@ class PlatformTemplateContent(PluginTemplateExtension):
                 },
             )
         else:
-            drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
+            drives_id = Drive.objects.filter(content_type=parent_object_type, object_id=obj)
             partition_dict = {}
-            for drive_id in drives_id:
-                print(f"Drive ID: {drive_id['drive']}")
-                drive = Drive.objects.get(pk=drive_id['drive'])
-
+            for drive in drives_id:
                 drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
                 linux_device_type_id = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
                 # Get Linux Device of Drive e.g. /dev/sda
                 linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id,
-                                                             object_id=drive_id['drive'],
+                                                             object_id=drive.pk,
                                                              type='Disk')
 
                 if LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
